import { __awaiter } from "tslib";
import { logger } from '@sentry/utils';
import { NATIVE } from '../wrapper';
/** Loads runtime JS modules from prepared file. */
export class ModulesLoader {
    constructor() {
        /**
         * @inheritDoc
         */
        this.name = ModulesLoader.id;
    }
    /**
     * @inheritDoc
     */
    setupOnce(addGlobalEventProcessor) {
        let isSetup = false;
        let modules;
        addGlobalEventProcessor((event) => __awaiter(this, void 0, void 0, function* () {
            if (!isSetup) {
                try {
                    modules = yield NATIVE.fetchModules();
                }
                catch (e) {
                    logger.log(`Failed to get modules from native: ${e}`);
                }
                isSetup = true;
            }
            if (modules) {
                event.modules = Object.assign(Object.assign({}, modules), event.modules);
            }
            return event;
        }));
    }
}
/**
 * @inheritDoc
 */
ModulesLoader.id = 'ModulesLoader';
//# sourceMappingURL=modulesloader.js.map